@@ -32,6 +32,7 @@ describe 'tripleo::profile::base::nova' do
         is_expected.to_not contain_class('nova::config')
         is_expected.to_not contain_class('nova::logging')
         is_expected.to_not contain_class('nova::cache')
+        is_expected.to_not contain_class('nova::cinder')
         is_expected.to_not contain_class('nova::glance')
         is_expected.to_not contain_class('nova::placement')
         is_expected.to_not contain_class('nova::keystone::service_user')
@@ -55,8 +56,9 @@ describe 'tripleo::profile::base::nova' do
         is_expected.to contain_class('nova::config')
         is_expected.to contain_class('nova::logging')
         is_expected.to contain_class('nova::cache').with(
-          :memcache_servers => ['controller-1:11211']
+          :memcache_servers => ['127.0.0.1:11211']
         )
+        is_expected.to contain_class('nova::cinder')
         is_expected.to contain_class('nova::glance')
         is_expected.to contain_class('nova::placement')
         is_expected.to contain_class('nova::keystone::service_user')
@@ -77,6 +79,7 @@ describe 'tripleo::profile::base::nova' do
         is_expected.to_not contain_class('nova::config')
         is_expected.to_not contain_class('nova::logging')
         is_expected.to_not contain_class('nova::cache')
+        is_expected.to_not contain_class('nova::cinder')
         is_expected.to_not contain_class('nova::glance')
         is_expected.to_not contain_class('nova::placement')
         is_expected.to_not contain_class('nova::keystone::service_user')
@@ -102,6 +105,7 @@ describe 'tripleo::profile::base::nova' do
         is_expected.to contain_class('nova::config')
         is_expected.to contain_class('nova::logging')
         is_expected.to contain_class('nova::cache')
+        is_expected.to contain_class('nova::cinder')
         is_expected.to contain_class('nova::glance')
         is_expected.to contain_class('nova::placement')
         is_expected.to contain_class('nova::keystone::service_user')
